.ve_slider_menu[data-v-04407d9e]{cursor:pointer;margin-right:10px}.ve_slider_menu i[data-v-04407d9e]{font-size:40px}.ve_slider_menu:hover i[data-v-04407d9e]{color:#409eff}.ve_personal[data-v-1f447c67]{flex:1;align-items:center;text-align:right}.ve_personal[data-v-1f447c67] .el-dropdown{vertical-align:baseline!important}.ve_personal .ve_nav_dropdown[data-v-1f447c67]{font-weight:700}.ve_nav_bar[data-v-3d79b205]{display:flex;align-items:center;height:100%}.ve_menu_logo[data-v-58de8b74]{width:100%;height:50px;white-space:nowrap;overflow:hidden}.ve_menu_logo .ve_logo_img[data-v-58de8b74]{height:100%;text-align:center;width:65px;display:inline-block;box-sizing:border-box;vertical-align:middle}.ve_menu_logo .ve_logo_title[data-v-58de8b74]{width:160px;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;display:inline-block;margin:0;vertical-align:middle;color:#000}.ve_menu_logo .ve_logo_title[data-v-58de8b74]:hover{color:#409eff}li.el-menu-item.is-active{background-color:#31363a!important}.el-menu-item .el-icon svg,.el-sub-menu__title .el-icon svg{vertical-align:unset}a[data-v-24c70b3a]:active{color:#409eff}.ve_el_menu[data-v-24c70b3a]{background:#545c64;height:calc(100vh - var(--638d0422))}.el-main[data-v-11fccfd7]{height:calc(100vh - var(--1a671268));background:#f5f5f5}.el-main[data-v-11fccfd7] .el-scrollbar__bar.is-horizontal{visibility:hidden}