(self.webpackChunkwechaty_ui=self.webpackChunkwechaty_ui||[]).push([[292],{3121:e=>{e.exports={main_bg_color:"#f5f5f5",base_color:"#409EFF",nav_height:"50px",side_close_width:"65px",side_open_width:"160px",sideBgColor:"#545c64",sideTextColor:"#fff",sideActiveTextColor:"#ffd04b"}},292:(e,n,a)=>{"use strict";a.r(n),a.d(n,{default:()=>s});var t=a(9963),i=a(2262),o=a(6252),r=a(3121),l=a(6456),c={"element-loading-text":"拼命加载中","element-loading-spinner":"el-icon-loading"},u=["src"];const f={__name:"IFrame",setup:function(e){(0,t.sj)((function(e){return{"019f05cc":(0,i.SU)(r.nav_height)}}));var n=(0,l.yj)().query.url||"",a=(0,i.iH)(!0),f=(0,i.iH)(null);return(0,o.bv)((function(){var e;e=function(){a.value=!1},f.value.attachEvent?f.value.attachEvent("onload",e):f.value.onload=e})),function(e,t){var r=(0,o.Q2)("loading");return(0,o.wy)(((0,o.wg)(),(0,o.iD)("div",c,[(0,o._)("iframe",{ref_key:"iframe",ref:f,src:(0,i.SU)(n),frameborder:"0"},null,8,u)])),[[r,a.value]])}}};const s=(0,a(3744).Z)(f,[["__scopeId","data-v-3a88552e"]])}}]);