.ve_404[data-v-5e23014c]{height:100vh;width:100vw;position:relative;overflow:hidden;background:linear-gradient(90deg,#2f3640 23%,#181b20)}.moon[data-v-5e23014c]{background:linear-gradient(90deg,#d0d0d0 48%,#919191);position:absolute;top:-30vh;left:-80vh;width:160vh;height:160%;content:"";border-radius:50%;box-shadow:0 0 30px -4px rgba(0,0,0,.5)}.moon__crater[data-v-5e23014c]{position:absolute;content:"";border-radius:100%;background:linear-gradient(90deg,#7a7a7a 38%,#c3c3c3);opacity:.6}.moon__crater1[data-v-5e23014c]{top:250px;left:500px;width:60px;height:180px}.moon__crater2[data-v-5e23014c]{top:650px;left:340px;width:40px;height:80px;transform:rotate(55deg)}.moon__crater3[data-v-5e23014c]{top:-20px;left:40px;width:65px;height:120px;transform:rotate(250deg)}.star[data-v-5e23014c]{color:gray;position:absolute;width:10px;height:10px;content:"";border-radius:100%;transform:rotate(250deg);opacity:.4;-webkit-animation-name:shimmer-5e23014c;animation-name:shimmer-5e23014c;-webkit-animation-duration:1.5s;animation-duration:1.5s;-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite;-webkit-animation-direction:alternate;animation-direction:alternate}@-webkit-keyframes shimmer-5e23014c{0%{opacity:0}to{opacity:.7}}@keyframes shimmer-5e23014c{0%{opacity:0}to{opacity:.7}}.star1[data-v-5e23014c]{top:40%;left:50%;-webkit-animation-delay:1s;animation-delay:1s}.star2[data-v-5e23014c]{top:60%;left:90%;-webkit-animation-delay:3s;animation-delay:3s}.star3[data-v-5e23014c]{top:10%;left:70%;-webkit-animation-delay:2s;animation-delay:2s}.star4[data-v-5e23014c]{top:90%;left:40%}.star5[data-v-5e23014c]{top:20%;left:30%;-webkit-animation-delay:.5s;animation-delay:.5s}.astronaut[data-v-5e23014c]{position:absolute;width:60vw;height:100vh;top:0;right:0;z-index:0}.error[data-v-5e23014c]{position:absolute;left:100px;top:400px;transform:translateY(-60%);font-family:Righteous,cursive;color:#363e49;z-index:1}.error__title[data-v-5e23014c]{font-size:10em;font-weight:700;color:#d0d0d0;text-shadow:-5px -5px 0 rgba(0,0,0,.7);background-image:linear-gradient(90deg,#d0d0d0 48%,#919191);-webkit-background-clip:text;-webkit-text-fill-color:transparent}.error__subtitle[data-v-5e23014c]{font-size:2em}.error__description[data-v-5e23014c]{opacity:.5}.error__button[data-v-5e23014c]{min-width:7em;margin-top:3em;margin-right:.5em;padding:.5em 2em;outline:none;border:2px solid #2f3640;background-color:transparent;border-radius:8em;color:#576375;cursor:pointer;transition-duration:.2s;font-size:.75em;font-family:Righteous,cursive}.error__button[data-v-5e23014c]:hover{color:#21252c}.error__button--active[data-v-5e23014c]{background-color:#409eff;border:2px solid #409eff;color:#fff}.error__button--active[data-v-5e23014c]:hover{box-shadow:0 0 8px 0 rgba(0,0,0,.5);color:#fff}.ve_container[data-v-5b557b8e]{position:absolute;z-index:1;width:400px;top:50%;left:100px;transform:translateY(-50%);transition:all 1s;min-height:273px;text-align:center}.ve_container h1[data-v-5b557b8e]{font-size:24px;transition:all 1s;font-weight:700;margin-bottom:36px}.ve_container .ve_form .ve_submit[data-v-5b557b8e]{width:100%}.ve_container .ve_form[data-v-5b557b8e] .el-input-group__prepend{padding:0 10px}