"use strict";(self.webpackChunkwechaty_ui=self.webpackChunkwechaty_ui||[]).push([[298],{3298:(e,u,n)=>{n.r(u),n.d(u,{default:()=>l});var t=n(6252),r={class:"ve_home"},a=(0,t.Uk)(" 欢迎使用Wechaty-ui ");const c={},l=(0,n(3744).Z)(c,[["render",function(e,u){var n=(0,t.up)("el-col"),c=(0,t.up)("el-row");return(0,t.wg)(),(0,t.iD)("div",r,[(0,t.Wm)(c,null,{default:(0,t.w5)((function(){return[(0,t.Wm)(n,{span:16},{default:(0,t.w5)((function(){return[a]})),_:1})]})),_:1})])}]])}}]);